from ..utils.error import errorInvalidAccessToken, errorBreakApi
from ..utils.microservices import Microservice
from ..utils.request import Request, GET


class WorkspaceGateway:

    @classmethod
    def getUser(cls, accessToken, headers, language):
        response = Request.fetch(
            url="{baseUrl}/workspace/access-token/{accessToken}".format(baseUrl=Microservice.getBaseUrl(Microservice.workspace), accessToken=accessToken),
            method=GET,
            headers=headers,
            deadline=50
        )

        if response.status == 400:
            return None, response.contentJson()
        elif response.status > 200:
            return None, errorInvalidAccessToken(language=language)

        return response.contentJson()["user"], None

    @classmethod
    def getInfo(cls, workspaceId, headers, language):
        response = Request.fetch(
            url="{baseUrl}/workspace/{workspaceId}/owner".format(baseUrl=Microservice.getBaseUrl(Microservice.workspace), workspaceId=workspaceId),
            headers=headers
        )

        if response.status != 200:
            return None, errorBreakApi(language=language)

        return response.contentJson(), None
